pub fn invert_unit_upper_triangular<T: ComplexField>(
dst: MatMut<'_, T>,
src: MatRef<'_, T>,
par: Par,
)Expand description
computes the inverse of the upper triangular matrix src (with implicit unit
diagonal) and stores the strictly upper triangular part of the result to dst.
panics
panics if src and dst have mismatching dimensions, or if they are not square.